# procs-dgraph-ofbiz.md
## start
```sh
$ python -m sagas.ofbiz.entity_graph get_schema Example
$ python -m sagas.ofbiz.entity_graph setup_schema_head Example # (重置dgraph-schemas)
$ python -m sagas.graph.graph_manager get_current_schema
```


